Changelog
=========

0.2.0
-----

- |removed| Python 2 support.
- |added| Python 3.7 and 3.8 testing.

0.1.5
-----

- |fixed| package release on TravisCI.

0.1.4
-----

- |fixed| sdist packaging.

0.1.3
-----

- |fixed| TravisCI deployment.

0.1.2
-----

- |fixed| Image alignment flags.
- |fixed| ReadtheDocs injected version box styling.

.. |fixed| image:: https://img.shields.io/badge/-fixed-success.svg
              :class: badge
.. |added| image:: https://img.shields.io/badge/-added-seagreen.svg
              :class: badge
.. |changed| image:: https://img.shields.io/badge/-changed-informational.svg
                :class: badge
.. |removed| image:: https://img.shields.io/badge/-removed-slategrey.svg
                :class: badge
.. |deprecated| image:: https://img.shields.io/badge/-deprecated-lightgrey.svg
                   :class: badge
.. |security| image:: https://img.shields.io/badge/-security-tomato.svg
                 :class: badge
